//
// Copyright (c) 2012 Samsung Electronics Co., Ltd.
//
// Licensed under the Flora License, Version 1.1 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://floralicense.org/license/
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an AS IS BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

#include <new>
#include <FUi.h>
#include <FGraphics.h>
#include <FMediaImage.h>
#include <FAppApp.h>
#include "GalleryAppWidgetProvider.h"
#include "GalleryAppWidgetFrame.h"

using namespace Tizen::Base;
using namespace Tizen::Graphics;
using namespace Tizen::Ui;
using namespace Tizen::Ui::Controls;
using namespace Tizen::Media;
using namespace Tizen::App;

const wchar_t GALLERY_IMAGE_PATH_T[] = L"res/screen-density-xhigh/t.png";
const wchar_t GALLERY_IMAGE_PATH_I[] = L"res/screen-density-xhigh/i.png";
const wchar_t GALLERY_IMAGE_PATH_Z[] = L"res/screen-density-xhigh/z.png";
const wchar_t GALLERY_IMAGE_PATH_E[] = L"res/screen-density-xhigh/e.png";
const wchar_t GALLERY_IMAGE_PATH_N[] = L"res/screen-density-xhigh/n.png";

GalleryAppWidgetFrame::GalleryAppWidgetFrame(void)
	: __pLabel(null)
	, __pImage(null)
{

}

GalleryAppWidgetFrame::~GalleryAppWidgetFrame(void)
{
	delete __pImage;
}

result
GalleryAppWidgetFrame::OnInitializing(void)
{
	// TODO:
	// Add your initialization code here
	AppLog("Initializing GalleryAppWidgetFrame...");

	__pLabel = new (std::nothrow) Label();

	Rectangle bounds = GetBounds();
	__pLabel->Construct(bounds, L"TIZEN");
	__pLabel->SetName(L"Label");
	__pLabel->SetTextVerticalAlignment(ALIGNMENT_TOP);
	__pLabel->SetTextHorizontalAlignment(ALIGNMENT_LEFT);
	__pLabel->AddTouchEventListener(*this);
	AddControl(__pLabel);

	Update();

	return E_SUCCESS;
}

void
GalleryAppWidgetFrame::Update(void)
{
	const wchar_t* IMAGE_PATHS[5] =
	{
		GALLERY_IMAGE_PATH_T,
		GALLERY_IMAGE_PATH_I,
		GALLERY_IMAGE_PATH_Z,
		GALLERY_IMAGE_PATH_E,
		GALLERY_IMAGE_PATH_N
	};

	Image image;
	image.Construct();

	int index = GalleryAppWidgetState::GetIndex();

	if( __pImage )
	{
		delete __pImage;
		__pImage = null;
	}
	AppLog("image changed to (%ls)", IMAGE_PATHS[index]);
	__pImage = image.DecodeN(App::GetInstance()->GetAppRootPath() + IMAGE_PATHS[index], BITMAP_PIXEL_FORMAT_ARGB8888);

	AppAssert(__pImage);
	__pLabel->SetBackgroundBitmap(*__pImage);
	__pLabel->SetText(Integer::ToString(index));

	Invalidate(true);
}

result
GalleryAppWidgetFrame::OnTerminating(void)
{
	// TODO:
	// Add your termination code here
	result r = E_SUCCESS;

	return r;
}

void
GalleryAppWidgetFrame::OnBoundsChanged(const Tizen::Graphics::Rectangle& oldRect, const Tizen::Graphics::Rectangle& newRect)
{
	// TODO:
	// Add your code to resize AppWidget here
	if (__pLabel)
	{
		Rectangle bounds = GetBounds();
		__pLabel->SetSize(Dimension(bounds.width, bounds.height));
	}
}

void
GalleryAppWidgetFrame::OnTouchReleased(const Tizen::Ui::Control& source, const Tizen::Graphics::Point& currentPosition, const Tizen::Ui::TouchEventInfo& touchInfo)
{
	// TODO:
	// Add your touch event handler code here, such as launching UI application.
	int index = GalleryAppWidgetState::GetIndex();
	index = (index == 4)? 0 : index+1;
	GalleryAppWidgetState::SetIndex(index);

	Update();
}
